@@ -291,9 +291,22 @@ GAMGI_CHEM_FILTER_IDENTICAL, GAMGI_CHEM_FILTER_NONE };
  * used to calculate optimum radius in H orbitals *
  **************************************************/
 
-#define GAMGI_CHEM_ORBITAL_SHIFT 2.0
-#define GAMGI_CHEM_ORBITAL_MAX  50.0
-#define GAMGI_CHEM_ORBITAL_STEP 0.01
+#define GAMGI_CHEM_ORBITAL_R_SHIFT 2.0
+#define GAMGI_CHEM_ORBITAL_R_MAX  50.0
+#define GAMGI_CHEM_ORBITAL_R_STEP 0.01
+
+/*************************************
+ * tested against H orbital (6,5,-5) *
+ *************************************/
+
+#define GAMGI_CHEM_ORBITAL_T_STEP 0.04
+#define GAMGI_CHEM_ORBITAL_P_STEP 0.04
+
+/*****************************************************************
+ * minimum r distance accepted, to avoid division by zero issues *
+ *****************************************************************/
+
+#define GAMGI_CHEM_ORBITAL_R_MIN 1E-8
 
 /*************************************************************
  * used to build wired H orbitals: default density,          *
@@ -305,15 +318,16 @@ GAMGI_CHEM_FILTER_IDENTICAL, GAMGI_CHEM_FILTER_NONE };
 #define GAMGI_CHEM_ORBITAL_POINTS   50000
 #define GAMGI_CHEM_ORBITAL_BAD       1000
 
-/************************************************************
- * used to build solid H orbitals: default number of slices *
- * per octant, maximum number of slices per octant, initial *
- * size and increment for points arrays                     *
- ************************************************************/
+/**************************************************************
+ * used to build solid H orbitals: default number of slices   *
+ * per octant, maximum number of slices per octant, initial   *
+ * size and increment for points arrays (should be a multiple *
+   of 3 (points per triangle) x 8 (bits per byte) = 24        *
+ **************************************************************/
 
 #define GAMGI_CHEM_ORBITAL_SLICES      50
 #define GAMGI_CHEM_ORBITAL_SLICES_MAX 255
-#define GAMGI_CHEM_ORBITAL_SEGMENT    100
+#define GAMGI_CHEM_ORBITAL_SEGMENT    120
 
 /***************************************
  * default orbital origin, orientation *
