@@ -34,6 +34,18 @@
 #define GAMGI_ENGINE_STRING 50
 #define GAMGI_ENGINE_LINE  200
 
+/**********************************************
+ *              arrays of bits                *
+ * source: http://c-faq.com/misc/bitsets.html *
+ **********************************************/
+
+#define GAMGI_ENGINE_BITMASK(b) (1 << ((b) % CHAR_BIT))
+#define GAMGI_ENGINE_BITSLOT(b) ((b) / CHAR_BIT)
+#define GAMGI_ENGINE_BITSET(a, b) ((a)[GAMGI_ENGINE_BITSLOT(b)] |= GAMGI_ENGINE_BITMASK(b))
+#define GAMGI_ENGINE_BITCLEAR(a, b) ((a)[GAMGI_ENGINE_BITSLOT(b)] &= ~GAMGI_ENGINE_BITMASK(b))
+#define GAMGI_ENGINE_BITTEST(a, b) ((a)[GAMGI_ENGINE_BITSLOT(b)] & GAMGI_ENGINE_BITMASK(b))
+#define GAMGI_ENGINE_BITNSLOTS(nb) ((nb + CHAR_BIT - 1) / CHAR_BIT)
+
 /********** types *********
  **************************/
 
@@ -172,8 +184,7 @@ int sampling, seed;
 
 gamgi_bool phase, frame;
 int octants[8];
-gamgi_bool axes;
-double length;
+double axes;
 
 /**************
  * array data *
