@@ -120,8 +120,7 @@ orbital->seed = 0;
 orbital->phase = FALSE;
 orbital->frame = FALSE;
 for (i = 0; i < 8; i++) orbital->octants[i] = 0;
-orbital->axes = FALSE;
-orbital->length = 0.0;
+orbital->axes = 0.0;
 
 orbital->dots[0] = 0;
 orbital->dots[1] = 0;
