@@ -292,9 +292,9 @@ if (orbital->style != GAMGI_MESA_ORBITAL_STYLE)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-if (fabs (orbital->density - GAMGI_CHEM_ORBITAL_DENSITY) > GAMGI_MATH_TOLERANCE)
+if (fabs (orbital->density - GAMGI_CHEM_ORBITAL_DENSITY) > GAMGI_MATH_TOLERANCE_ORBITAL)
   {
-  sprintf (string, "%.*E", 1, orbital->density);
+  sprintf (string, "density=\"%.*E\"", 1, orbital->density);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
@@ -336,9 +336,9 @@ if (strcmp (token, "11111111") != 0)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-if (orbital->axes == TRUE)
+if (orbital->axes > 0.0)
   {
-  sprintf (string, "length=\"%.*f\"", gamgi->gamgi->length, orbital->length);
+  sprintf (string, "axes=\"%.*f\"", gamgi->gamgi->length, orbital->axes);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
