@@ -44,17 +44,13 @@ static void static_number (GtkWidget *widget, void *data);
 static void static_default (int number, char *name, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
-GtkWidget *entry_atom;
-GtkWidget *entry_mass, *entry_radius, *entry_charge;
+GtkWidget *entry_mass, *entry_radius;
 GtkWidget *entry_red, *entry_green, *entry_blue;
 char token[GAMGI_ENGINE_TOKEN];
 double radius;
 
-entry_atom = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom");
-
 entry_mass = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_mass");
 entry_radius = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_radius");
-entry_charge = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_charge");
 
 entry_red = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
 entry_green = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
