@@ -1231,11 +1231,11 @@ else if (strcmp (name, "Size") == 0)
   dlist_new = static_ok_size (dlist_old, action, window);
 else if (strcmp (name, "Variancy") == 0)
   dlist_new = static_ok_variancy (dlist_old, action, window);
-else if (strcmp (name, "Red") == 0)
+else if (strcmp (name, "R") == 0)
   dlist_new = static_ok_red (dlist_old, action, window);
-else if (strcmp (name, "Green") == 0)
+else if (strcmp (name, "G") == 0)
   dlist_new = static_ok_green (dlist_old, action, window);
-else if (strcmp (name, "Blue") == 0)
+else if (strcmp (name, "B") == 0)
   dlist_new = static_ok_blue (dlist_old, action, window);
 else if (strcmp (name, "Scale") == 0)
   dlist_new = static_ok_scale (dlist_old, action, window);
