@@ -1232,8 +1232,7 @@ gtk_widget_show (table);
 
 button = gtk_toggle_button_new_with_label (" Color ");
 gtk_table_attach (GTK_TABLE (table), button, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
-g_signal_connect (button, "clicked",
-G_CALLBACK (static_color), window);
+g_signal_connect (button, "clicked", G_CALLBACK (static_color), window);
 g_object_set_data (G_OBJECT (dialog), "button_color", button);
 gtk_widget_show (button);
 
