@@ -21,6 +21,7 @@
 #include "gamgi_engine_create.h"
 #include "gamgi_engine_start.h"
 #include "gamgi_engine_remove.h"
+#include "gamgi_engine_list.h"
 #include "gamgi_engine_dlist.h"
 #include "gamgi_engine_filter.h"
 #include "gamgi_engine_find.h"
@@ -32,6 +33,7 @@
 #include "gamgi_gtk_cell_symmetry.h"
 #include "gamgi_gtk_direction_create.h"
 #include "gamgi_gtk_direction_range.h"
+#include "gamgi_gtk_direction_list.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_math_position.h"
@@ -189,7 +191,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_CONVENTIONAL - 1);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_DIRECTION_VECTORS - 1);
 }
 
 static void static_end_atom (gamgi_window *window)
@@ -315,6 +317,16 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+/**************************
+ * reset atom identifiers *
+ **************************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom1");
+gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom2");
+gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
 
 /******************** internal function ****************
@@ -344,7 +356,7 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 GtkWidget *combo;
 const char *name;
-char token[GAMGI_ENGINE_TOKEN];
+char token[GAMGI_ENGINE_TOKEN] = "";
 
 direction->reference = GAMGI_ENGINE_CELL;
 
@@ -367,32 +379,36 @@ if (*cell == NULL)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_u");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &direction->uvw[0], -INT_MAX, INT_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Direction Data", window);
-  gamgi_engine_remove_direction (direction);
-  return FALSE;
-  }
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &direction->uvw[1], -INT_MAX, INT_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Direction Data", window);
-  gamgi_engine_remove_direction (direction);
-  return FALSE;
-  }
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &direction->uvw[2], -INT_MAX, INT_MAX) == FALSE)
+if (gtk_widget_is_sensitive (entry) == TRUE &&
+gamgi_io_token_int_scan (name, &direction->uvw[0], -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid direction indices", window);
   gamgi_engine_remove_direction (direction);
   return FALSE;
   }
 
-if (gamgi_phys_direction_zero (direction->uvw) == TRUE)
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gtk_widget_is_sensitive (entry) == TRUE &&
+gamgi_io_token_int_scan (name, &direction->uvw[1], -INT_MAX, INT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid direction indices", window);
+  gamgi_engine_remove_direction (direction);
+  return FALSE;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gtk_widget_is_sensitive (entry) == TRUE &&
+gamgi_io_token_int_scan (name, &direction->uvw[2], -INT_MAX, INT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid direction indices", window);
+  gamgi_engine_remove_direction (direction);
+  return FALSE;
+  }
+
+if (gtk_widget_is_sensitive (entry) == TRUE &&
+gamgi_phys_direction_zero (direction->uvw) == TRUE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid direction indices", window);
   gamgi_engine_remove_direction (direction);
@@ -403,11 +419,12 @@ if (gamgi_phys_direction_zero (direction->uvw) == TRUE)
  * get direction name *
  **********************/
 
-sprintf (token, "[%d.%d.%d]", direction->uvw[0], direction->uvw[1], direction->uvw[2]);
+if (gtk_widget_is_sensitive (entry) == TRUE)
+  sprintf (token, "[%d.%d.%d]", direction->uvw[0], direction->uvw[1], direction->uvw[2]);
 if (gamgi_gtk_object_name (dialog, "entry_direction",
 token, direction->object.name) == FALSE)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Direction Name", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid direction name", window);
   gamgi_engine_remove_direction (direction);
   return FALSE;
   }
@@ -478,8 +495,9 @@ if (gamgi_phys_direction_length ((*atom1)->position, (*atom2)->position) == FALS
 return TRUE;
 }
 
-static gamgi_bool static_ok_scope (gamgi_direction *direction, 
-gamgi_cell *cell, gamgi_window *window)
+static gamgi_bool static_ok_scope (gamgi_direction *direction,
+gamgi_cell *cell, double *thickness, gamgi_enum *structure,
+gamgi_enum *filter, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
@@ -491,10 +509,10 @@ const char *name;
  **********************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_structure");
-direction->structure = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+*structure = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_filter");
-direction->filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+*filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /**************************
  * get scanning thickness *
@@ -502,7 +520,7 @@ direction->filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &direction->thickness, 
+if (gamgi_io_token_double_scan (name, thickness, 
 GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid thickness data", window);
@@ -691,10 +709,12 @@ gamgi_object *parent;
 gamgi_dlist *dlist;
 GtkWidget *button;
 double zero[3];
+double thickness;
 int hkl1[3], hkl2[3];
 int start1, end1;
 int start2, end2;
 gamgi_enum pole, trace;
+gamgi_enum structure, filter;
 
 direction = gamgi_engine_create_direction ();
 gamgi_engine_start_direction (direction);
@@ -725,7 +745,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
     }
   else
     {
-    if (static_ok_scope (direction, cell, window) == FALSE) return;
+    if (static_ok_scope (direction, cell, &thickness,
+    &structure, &filter, window) == FALSE) return;
     }
   }
 else
@@ -735,7 +756,8 @@ else
    *******************************/
 
   if (static_ok_atoms (direction, &atom1, &atom2, window) == FALSE) return;
-  if (static_ok_scope (direction, NULL, window) == FALSE) return;
+  if (static_ok_scope (direction, NULL, &thickness,
+  &structure, &filter, window) == FALSE) return;
   }
 if (static_ok_view (direction, window) == FALSE) return;
 
@@ -756,17 +778,25 @@ if (direction->reference == GAMGI_ENGINE_CELL)
    * this is a crystallographic direction *
    ****************************************/
 
-  if (cell->type == GAMGI_PHYS_PROJECTION)
-    gamgi_phys_direction_projection (direction, cell, pole, trace);
-  else
+  dlist = NULL;
+  if (cell->type != GAMGI_PHYS_PROJECTION)
     {
-    if (gamgi_gtk_direction_range_get (cell->lattice, direction->vectors, 
-    hkl1, hkl2, &start1, &end1, &start2, &end2) == TRUE)
-      gamgi_phys_direction_range (direction, cell, 
-      hkl1, start1, end1, hkl2, start2, end2);
-    else
-      gamgi_phys_direction_node (direction, cell);
+    dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
+    dlist = gamgi_engine_filter_atom (dlist, 0, filter,
+    GAMGI_ENGINE_DIRECTION, GAMGI_CAST_OBJECT cell);
     }
+
+  if (gamgi_gtk_direction_range_get (cell->lattice, direction->vectors,
+  hkl1, hkl2, &start1, &end1, &start2, &end2) == TRUE)
+    gamgi_phys_direction_range (direction, cell, structure,
+    filter, thickness, dlist, hkl1, start1, end1, hkl2, start2, end2);
+  else
+    gamgi_gtk_direction_list_create (direction, cell,
+    structure, filter, thickness, dlist, pole, trace);
+
+  while (dlist != NULL)
+    dlist = gamgi_engine_dlist_remove_start (dlist);
+  gamgi_engine_remove_direction (direction);
   }
 
 if (direction->reference == GAMGI_ENGINE_ATOM)
@@ -778,12 +808,14 @@ if (direction->reference == GAMGI_ENGINE_ATOM)
    * the direction type is needed because of the rotation next *
    *************************************************************/
 
+  direction->type = GAMGI_PHYS_LINE;
+  direction->vectors = GAMGI_PHYS_DIRECTION_VECTORS;
+
   parent = gamgi_phys_direction_parent (atom1, atom2, window);
   dlist = gamgi_engine_dlist_atom_object (parent, NULL);
-  dlist = gamgi_engine_filter_atom (dlist, direction->filter,
-  GAMGI_ENGINE_DIRECTION, parent);
   dlist = gamgi_phys_direction_reorder (dlist, atom1, atom2);
-  direction->type = GAMGI_PHYS_LINE;
+  dlist = gamgi_engine_filter_atom (dlist, 2, filter, GAMGI_ENGINE_DIRECTION, parent);
+  if (parent->class <= GAMGI_ENGINE_DIRECTION) parent = GAMGI_CAST_OBJECT window->layer;
 
   /**********************************************************
    * reset and build direction line AFTER linking to parent *
@@ -795,8 +827,8 @@ if (direction->reference == GAMGI_ENGINE_ATOM)
   gamgi_math_position_direction_rotation_set (direction, zero);
   gamgi_math_position_direction_translation_set (direction, zero);
 
-  gamgi_phys_direction_atoms (direction, atom1, atom2, dlist, TRUE);
-  direction->vectors = GAMGI_PHYS_DIRECTION_VECTORS;
+  gamgi_phys_direction_atoms (direction, atom1,
+  atom2, dlist, structure, thickness, TRUE);
   }
 
 /************************   
@@ -833,7 +865,7 @@ gtk_widget_set_size_request (notebook, size.width, size.height);
  *********************************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_CONVENTIONAL - 1);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_DIRECTION_VECTORS - 1);
 static_cell (NULL, window);
 
 /*****************************
@@ -856,11 +888,12 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
-/******************************************
- * initialize data in second level dialog *
- ******************************************/
+/*******************************************
+ * initialize data in second level dialogs *
+ *******************************************/
 
 gamgi_gtk_direction_range_start (window);
+gamgi_gtk_direction_list_start (window);
 }
 
 static void static_press (gamgi_object *object, void *data)
@@ -983,6 +1016,48 @@ else
 
 }
 
+void gamgi_gtk_direction_create_uvw (gamgi_bool active, gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry_u, *entry_v, *entry_w;
+GtkWidget *label_u, *label_v, *label_w;
+
+entry_u = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_u");
+entry_v = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v");
+entry_w = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w");
+label_u = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_u");
+label_v = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v");
+label_w = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_w");
+
+/**************************************************************
+ * enable when one uvw diretcion family is directly specified *
+ **************************************************************/
+
+if (active == TRUE)
+  {
+  gtk_widget_set_sensitive (entry_u, TRUE);
+  gtk_widget_set_sensitive (entry_v, TRUE);
+  gtk_widget_set_sensitive (entry_w, TRUE);
+  gtk_widget_set_sensitive (label_u, TRUE);
+  gtk_widget_set_sensitive (label_v, TRUE);
+  gtk_widget_set_sensitive (label_w, TRUE);
+  }
+else
+  {
+  gtk_entry_set_text (GTK_ENTRY (entry_u), "");
+  gtk_entry_set_text (GTK_ENTRY (entry_v), "");
+  gtk_entry_set_text (GTK_ENTRY (entry_w), "");
+
+  gtk_widget_set_sensitive (entry_u, FALSE);
+  gtk_widget_set_sensitive (entry_v, FALSE);
+  gtk_widget_set_sensitive (entry_w, FALSE);
+  gtk_widget_set_sensitive (label_u, FALSE);
+  gtk_widget_set_sensitive (label_v, FALSE);
+  gtk_widget_set_sensitive (label_w, FALSE);
+  }
+
+}
+
 /******************** external function *****************
  *                                                      *
  *              GAMGI_GTK_DIRECTION_CREATE              *
@@ -1015,6 +1090,8 @@ gamgi_bool *sensitive;
 dialog = gamgi_gtk_dialog_task0_create ("Direction Create", window);
 window->action = GAMGI_GTK_DIRECTION_CREATE;
 gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+g_signal_connect (dialog, "destroy",
+G_CALLBACK (gamgi_gtk_direction_list_destroy), window);
 
 /********************
  * global container *
@@ -1155,14 +1232,17 @@ gtk_widget_show (table);
 
 label = gtk_label_new ("U");
 gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_u", label);
 gtk_widget_show (label);
 
 label = gtk_label_new ("V");
 gtk_table_attach (GTK_TABLE (table), label, 4, 5, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_v", label);
 gtk_widget_show (label);
 
 label = gtk_label_new ("W");
 gtk_table_attach (GTK_TABLE (table), label, 6, 7, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_w", label);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
@@ -1192,9 +1272,11 @@ G_CALLBACK (static_instance), window);
 g_object_set_data (G_OBJECT (dialog), "entry_w", entry);
 gtk_widget_show (entry);
 
-button = gtk_button_new_with_label (" Set ");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "button_set", button);
+g_signal_connect (button, "clicked",
+G_CALLBACK (gamgi_gtk_direction_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /*********************
@@ -1418,7 +1500,7 @@ store = gtk_list_store_new (1, G_TYPE_STRING);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Class", -1);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Child", -1);
+gtk_list_store_set (store, &iter, 0, "Parent", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Identical", -1);
 gtk_list_store_append (store, &iter);
