@@ -193,13 +193,17 @@ void gamgi_gtk_dialog_color_default (GtkWidget *widget, gamgi_window *window)
 GtkWidget *hbox;
 GtkWidget *label;
 GtkStyle *style;
+GList *list;
 
 /****************************************************
  * use the default color, taken from the time label *
  ****************************************************/
 
 hbox = gtk_statusbar_get_message_area (GTK_STATUSBAR (window->statusbar_time));
-label = GTK_WIDGET (gtk_container_get_children (GTK_CONTAINER (hbox))->data);
+list = gtk_container_get_children (GTK_CONTAINER (hbox));
+label = GTK_WIDGET (list->data);
+g_list_free (list);
+
 style = gtk_style_copy (gtk_widget_get_style (label));
 gtk_widget_set_style (widget, style);
 g_object_unref (style);
