@@ -548,8 +548,8 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Group",
 static void static_interfaces_group_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Group Create",
-"interfaces/group/create", data, 4, 1, "type", "scope",
-"tolerance", "view");
+"interfaces/group/create", data, 3, 1, "type", "scope",
+"view");
 }
 
 static void static_interfaces_group_copy (void *data)
@@ -580,7 +580,7 @@ static void static_interfaces_group_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Group Modify",
 "interfaces/group/modify", data, 4, 1, "type", "scope", 
-"tolerance", "view");
+"position", "view");
 }
 
 static void static_interfaces_group_modify_polytope (void *data)
@@ -655,8 +655,8 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Plane Link",
 static void static_interfaces_plane_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Plane Modify",
-"interfaces/plane/modify", data, 4, 1, "type", "projection",
-"scope", "view");
+"interfaces/plane/modify", data, 5, 1, "type", "projection",
+"scope", "position", "view");
 }
 
 static void static_interfaces_plane_measure (void *data)
@@ -705,8 +705,8 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Direction Link",
 static void static_interfaces_direction_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Direction Modify",
-"interfaces/direction/modify", data, 4, 1, "type", "projection", 
-"scope", "view");
+"interfaces/direction/modify", data, 5, 1, "type", "projection", 
+"scope", "position", "view");
 }
 
 static void static_interfaces_direction_measure (void *data)
@@ -827,12 +827,37 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Orbital",
 "keywords/orbital", data, 0, 0);
 }
 
+static void static_interfaces_orbital_create (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Create",
+"interfaces/orbital/create", data, 5, 1,
+"type", "model", "volume", "position", "view");
+}
+
+static void static_interfaces_orbital_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Copy",
+"interfaces/orbital/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_orbital_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Select", 
 "interfaces/orbital/select", data, 0, 0);
 }
 
+static void static_interfaces_orbital_link (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Link",
+"interfaces/orbital/link", data, 2, 1, "object", "shift");
+}
+
+static void static_interfaces_orbital_remove (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Remove",
+"interfaces/orbital/remove", data, 1, 1, "object");
+}
+
 static void static_interfaces_text (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Text", 
@@ -1522,7 +1547,11 @@ static_row (store, &iter2, "Remove", static_interfaces_bond_remove);
 static_row (store, &iter2, "Config", static_interfaces_bond_config);
 
 iter2 = static_row (store, &iter1, "Orbital", static_interfaces_orbital);
+static_row (store, &iter2, "Create", static_interfaces_orbital_create);
+static_row (store, &iter2, "Copy", static_interfaces_orbital_copy);
 static_row (store, &iter2, "Select", static_interfaces_orbital_select);
+static_row (store, &iter2, "Link", static_interfaces_orbital_link);
+static_row (store, &iter2, "Remove", static_interfaces_orbital_remove);
 
 iter2 = static_row (store, &iter1, "Text", static_interfaces_text);
 static_row (store, &iter2, "Create", static_interfaces_text_create);
