@@ -257,8 +257,16 @@ static void static_interfaces_bond_config (void *data);
 
 static void static_interfaces_orbital (void *data);
 
+static void static_interfaces_orbital_create (void *data);
+
+static void static_interfaces_orbital_copy (void *data);
+
 static void static_interfaces_orbital_select (void *data);
 
+static void static_interfaces_orbital_link (void *data);
+
+static void static_interfaces_orbital_remove (void *data);
+
 static void static_interfaces_text (void *data);
 
 static void static_interfaces_text_create (void *data);
