@@ -1215,11 +1215,11 @@ else if (strcmp (name, "Inside") == 0)
 else if (strcmp (name, "Outside") == 0)
   dlist_new = static_ok_outside (dlist_old, action, window);
 
-else if (strcmp (name, "Red") == 0)
+else if (strcmp (name, "R") == 0)
   dlist_new = static_ok_red (dlist_old, action, window);
-else if (strcmp (name, "Green") == 0)
+else if (strcmp (name, "G") == 0)
   dlist_new = static_ok_green (dlist_old, action, window);
-else if (strcmp (name, "Blue") == 0)
+else if (strcmp (name, "B") == 0)
   dlist_new = static_ok_blue (dlist_old, action, window);
 else if (strcmp (name, "Axes") == 0)
   dlist_new = static_ok_axes (dlist_old, action, window);
