@@ -29,6 +29,59 @@
 #include "gamgi_math_position.h"
 #include "gamgi_io_token.h"
 
+static void static_axes (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *combo;
+GtkWidget *entry;
+GtkWidget *label;
+GtkWidget *button;
+char token[GAMGI_ENGINE_TOKEN] = "";
+const char *name;
+double radius;
+int axes;
+gamgi_bool active;
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_radius");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_frame");
+active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
+axes = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_length");
+label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_length");
+
+if (axes == GAMGI_CHEM_AXES_NONE - 1)
+  {
+  gtk_widget_set_sensitive (entry, FALSE);
+  gtk_widget_set_sensitive (label, FALSE);
+  }
+else
+  {
+  gtk_widget_set_sensitive (entry, TRUE);
+  gtk_widget_set_sensitive (label, TRUE);
+
+  if (axes == GAMGI_CHEM_AXES_UNIT - 1)
+    sprintf (token, "%.*f", gamgi->gamgi->length, 1.0);
+
+  if (axes == GAMGI_CHEM_AXES_BOHR - 1)
+    sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_CHEM_A0);
+
+  if (axes == GAMGI_CHEM_AXES_FRAME - 1 && gamgi_io_token_double_scan (name,
+  &radius, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == TRUE)
+    {
+    if (active == TRUE) radius *= 2.0;
+    sprintf (token, "%.*f", gamgi->gamgi->length, radius);
+    }
+  }
+
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+}
+
 static void static_phase (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -89,10 +142,9 @@ GtkWidget *entry_red, *entry_green, *entry_blue;
 GtkWidget *label_red, *label_green, *label_blue;
 GtkWidget *label;
 GtkWidget *button;
-GtkWidget *combo;
-gamgi_bool *sensitive;
 char token[GAMGI_ENGINE_TOKEN];
-int axes;
+
+label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_frame");
 
 label_red = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_frame_red");
 label_green = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_frame_green");
@@ -102,11 +154,7 @@ entry_red = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_frame_red
 entry_green = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_frame_green");
 entry_blue = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_frame_blue");
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_axes");
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_frame");
 button = g_object_get_data (G_OBJECT (dialog), "button_frame");
-
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   {
   gtk_widget_set_sensitive (label, TRUE);
@@ -123,12 +171,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   gtk_entry_set_text (GTK_ENTRY (entry_green), token);
   sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, GAMGI_MESA_ORBITAL_FRAME_B);
   gtk_entry_set_text (GTK_ENTRY (entry_blue), token);
-
-  /***************
-   * update axes *
-   ***************/
-
-  sensitive[GAMGI_CHEM_AXES_FRAME - 1] = TRUE;
   }
 else
   {
@@ -143,59 +185,9 @@ else
   gtk_widget_set_sensitive (entry_red, FALSE);
   gtk_widget_set_sensitive (entry_green, FALSE);
   gtk_widget_set_sensitive (entry_blue, FALSE);
-
-  /***************
-   * update axes *
-   ***************/
-
-  axes = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-  if (axes == GAMGI_CHEM_AXES_FRAME - 1)
-    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_CHEM_AXES_NONE - 1);
-  sensitive[GAMGI_CHEM_AXES_FRAME - 1] = FALSE;
-  }
-}
-
-static void static_axes (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-GtkWidget *entry;
-GtkWidget *label;
-char token[GAMGI_ENGINE_TOKEN] = "";
-const char *name;
-double radius;
-int axes;
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_radius");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_length");
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_length");
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-axes = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-if (axes == GAMGI_CHEM_AXES_NONE - 1)
-  {
-  gtk_widget_set_sensitive (entry, FALSE);
-  gtk_widget_set_sensitive (label, FALSE);
-  }
-else
-  {
-  gtk_widget_set_sensitive (entry, TRUE);
-  gtk_widget_set_sensitive (label, TRUE);
-
-  if (axes == GAMGI_CHEM_AXES_UNIT - 1)
-    sprintf (token, "%.*f", gamgi->gamgi->length, 1.0);
-  if (axes == GAMGI_CHEM_AXES_BOHR - 1)
-    sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_CHEM_A0);
-  if (axes == GAMGI_CHEM_AXES_FRAME - 1 && gamgi_io_token_double_scan (name,
-  &radius, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == TRUE)
-    sprintf (token, "%.*f", gamgi->gamgi->length, 2.0 * radius);
   }
 
-gtk_entry_set_text (GTK_ENTRY (entry), token);
+static_axes (NULL, window);
 }
 
 static void static_style (GtkWidget *widget, void *data)
@@ -273,6 +265,12 @@ if (radius > 0.0)
   gtk_entry_set_text (GTK_ENTRY (entry), token);
   }
 else gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+/***************************
+ * set default axes length *
+ ***************************/
+
+static_axes (NULL, window);
 }
 
 static void static_l (GtkWidget *widget, void *data)
@@ -345,7 +343,6 @@ GtkWidget *button;
 GtkWidget *combo;
 const char *name;
 double origin[3], euler[3];
-int axes;
 
 orbital = gamgi_engine_create_orbital ();
 gamgi_engine_start_orbital (orbital);
@@ -459,20 +456,15 @@ button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_8");
 orbital->octants[7] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-axes = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (axes != GAMGI_CHEM_AXES_NONE - 1) orbital->axes = TRUE;
-
-if (orbital->axes == TRUE)
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_length");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gtk_combo_box_get_active (GTK_COMBO_BOX (combo)) != GAMGI_CHEM_AXES_NONE - 1
+&& gamgi_io_token_double_scan (name, &orbital->axes, GAMGI_MATH_TOLERANCE_LENGTH,
+DBL_MAX) == FALSE)
   {
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_length");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_double_scan (name, &orbital->length,
-  GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid axes length", window);
-    gamgi_engine_remove_orbital (orbital);
-    return;
-    }
+  gamgi_gtk_dialog_message_create ("Error", "Invalid axes length", window);
+  gamgi_engine_remove_orbital (orbital);
+  return;
   }
 
 /*************************
@@ -709,7 +701,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), token);
  ********************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_MESA_WIRED - 1);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_MESA_SOLID - 1);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_sampling");
 sprintf (token, "%d", GAMGI_CHEM_ORBITAL_POINTS);
@@ -1380,7 +1372,7 @@ gtk_list_store_set (store, &iter, 0, "Unit", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Bohr", -1);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Frame", -1);
+gtk_list_store_set (store, &iter, 0, "Radius", -1);
 gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
 g_object_unref (store);
 
@@ -1388,11 +1380,6 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-sensitive = gamgi_gtk_dialog_sensitive_create (4);
-g_object_set_data (G_OBJECT (dialog), "sensitive_axes", sensitive);
-gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
-renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
-
 entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
