@@ -683,6 +683,9 @@ static void static_list (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *label, *button;
+gamgi_bool *sensitive;
+
+sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_reference");
 
 label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_plane");
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
@@ -694,6 +697,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    **********************************/
 
   gtk_label_set_text (GTK_LABEL (label), "Plane");
+  sensitive[STATIC_REFERENCE_CELL] = TRUE;
+  sensitive[STATIC_REFERENCE_ATOMS] = TRUE;
   }
 else
   {
@@ -702,6 +707,8 @@ else
    **********************************************/
 
   gtk_label_set_text (GTK_LABEL (label), "Name");
+  sensitive[STATIC_REFERENCE_CELL] = FALSE;
+  sensitive[STATIC_REFERENCE_ATOMS] = FALSE;
   static_reset (window);
   }
 
@@ -1496,6 +1503,19 @@ if (new == TRUE)
 
   if (plane->reference == GAMGI_ENGINE_CELL)
     {
+    /**************************************************************
+     * Plane Create: plane is just a template, removed in the     *
+     * end, used to copy data to plane_new, the real plane        *
+     *                                                            *
+     * Plane Modify: plane is the real plane, the plane to modify *
+     *                                                            *
+     * plane->object.object is used here as a flag to distinguish *
+     * between the two cases. plane->object.object can be used    *
+     * because plane is always unlinked at this stage             *
+     **************************************************************/
+
+    plane->object.object = GAMGI_CAST_OBJECT cell;
+
     /************************************
      * this is a crystallographic plane *
      ************************************/
@@ -1518,7 +1538,6 @@ if (new == TRUE)
       while (dlist != NULL)
         dlist = gamgi_engine_dlist_remove_start (dlist);
       }
-    gamgi_engine_remove_plane (plane);
     }
 
   if (plane->reference == GAMGI_ENGINE_ATOM)
@@ -2096,6 +2115,11 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
+sensitive = gamgi_gtk_dialog_sensitive_create (3);
+g_object_set_data (G_OBJECT (dialog), "sensitive_reference", sensitive);
+gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
+renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
+
 /********
  * Cell *
  ********/
