@@ -44,6 +44,10 @@
 #include "gamgi_gtk_text_select.h"
 #include "gamgi_gtk_text_modify.h"
 #include "gamgi_gtk_text_remove.h"
+#include "gamgi_gtk_orbital_create.h"
+#include "gamgi_gtk_orbital_copy.h"
+#include "gamgi_gtk_orbital_link.h"
+#include "gamgi_gtk_orbital_remove.h"
 #include "gamgi_gtk_bond_config.h"
 #include "gamgi_gtk_bond_create.h"
 #include "gamgi_gtk_bond_select.h"
@@ -1133,12 +1137,12 @@ menu = gtk_menu_new ();
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_ORBITAL);
 g_object_set_data (G_OBJECT (button), "menu", menu);
 
-static_item_insert (menu, "Create", "grey", gamgi_gtk_orbital_create, window);
-static_item_insert (menu, "Copy", "grey", gamgi_gtk_orbital_copy, window);
+static_item_insert (menu, "Create", NULL, gamgi_gtk_orbital_create, window);
+static_item_insert (menu, "Copy", NULL, gamgi_gtk_orbital_copy, window);
 static_item_insert (menu, "Select", "grey", gamgi_gtk_orbital_select, window);
-static_item_insert (menu, "Link", "grey", gamgi_gtk_orbital_link, window);
+static_item_insert (menu, "Link", NULL, gamgi_gtk_orbital_link, window);
 static_item_insert (menu, "Modify", "grey", gamgi_gtk_orbital_modify, window);
-static_item_insert (menu, "Remove", "grey", gamgi_gtk_orbital_remove, window);
+static_item_insert (menu, "Remove", NULL, gamgi_gtk_orbital_remove, window);
 
 separator = gtk_menu_item_new ();
 gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
