@@ -344,6 +344,12 @@ GAMGI_MESA_SELECT_RESIZE };
 #define GAMGI_MESA_ORBITAL_FRAME_G 1.0
 #define GAMGI_MESA_ORBITAL_FRAME_B 1.0
 
+/*************************
+ * default orbital style *
+ *************************/
+
+#define GAMGI_MESA_ORBITAL_STYLE GAMGI_MESA_WIRED
+
 /**************************************************************************
  * Width recommended by Plotutils (the GNU package) to render western     *
  * Hershey fonts. They say:                                               *
