@@ -101,7 +101,7 @@ double radius, length;
  *******************************************************************/
 
 radius = orbital->radius; 
-if (orbital->dots[0] > 0)
+if (orbital->frame == TRUE)
   gamgi_math_vector_absolute (offset, -radius, -radius, -radius); 
 else
   gamgi_math_vector_zero (offset);
@@ -111,7 +111,7 @@ else
  * radius), 1.0, or the frame size (2 * radius)        *
  *******************************************************/
 
-length = orbital->length; 
+length = orbital->axes; 
 gamgi_math_vector_absolute (v1, length, 0.0, 0.0);
 gamgi_math_vector_absolute (v2, 0.0, length, 0.0);
 gamgi_math_vector_absolute (v3, 0.0, 0.0, length);
