@@ -104,17 +104,26 @@ if (orbital->style == GAMGI_MESA_WIRED)
   glLineWidth (4.0);
   if (dots[1] > 0)
     { glColor3f (orbital->base_r, orbital->base_g, orbital->base_b);
-      gamgi_mesa_render_points (dots[1], orbital->points + 3 * dots[0]); }
+      gamgi_mesa_render_points (dots[1],
+      orbital->points + 3 * dots[0]); }
   if (dots[2] > 0)
     { glColor3f (orbital->phase_r, orbital->phase_g, orbital->phase_b);
-      gamgi_mesa_render_points (dots[2], orbital->points + 3 * dots[0] + 3 * dots[1]); }
+      gamgi_mesa_render_points (dots[2],
+      orbital->points + 3 * dots[0] + 3 * dots[1]); }
   glLineWidth (1.0);
   }
-else
+
+if (orbital->style == GAMGI_MESA_SOLID)
   {
   glDisable (GL_CULL_FACE);
-  glColor3f (orbital->base_r, orbital->base_g, orbital->base_b);
-  gamgi_mesa_render_triangles (dots[1] / 3, orbital->points + 3 * dots[0]);
+  if (dots[1] > 0)
+    { glColor3f (orbital->base_r, orbital->base_g, orbital->base_b);
+      gamgi_mesa_render_triangles (dots[1] / 3,
+      orbital->points + 3 * dots[0]); }
+  if (dots[2] > 0)
+    { glColor3f (orbital->phase_r, orbital->phase_g, orbital->phase_b);
+      gamgi_mesa_render_triangles (dots[2] / 3,
+      orbital->points + 3 * dots[0] + 3 * dots[1]); }
   glEnable (GL_CULL_FACE);
   }
 
