@@ -115,6 +115,8 @@ int level, int offset, gamgi_object **objects, int *levels)
 {
 gamgi_dlist *dlist;
 unsigned char color_old[3], color_new[3];
+double rotate[16];
+int *dots;
 
 if (class == GAMGI_ENGINE_ORBITAL)
   {
@@ -145,6 +147,41 @@ if (class == GAMGI_ENGINE_ORBITAL)
   if (level == 1) objects[offset] = GAMGI_CAST_OBJECT orbital;
   }
 
+glPushMatrix ();
+
+glTranslatef (orbital->center[0], orbital->center[1], orbital->center[2]);
+glScalef (orbital->object.scale, orbital->object.scale, orbital->object.scale);
+glTranslatef (-orbital->center[0], -orbital->center[1], -orbital->center[2]);
+
+/***********************
+ * draw orbital object *
+ ***********************/
+
+if (class >= GAMGI_ENGINE_ORBITAL)
+  {
+  glPushMatrix ();
+
+  glTranslatef (orbital->origin[0], orbital->origin[1], orbital->origin[2]);
+  gamgi_math_quaternion_to_matrix4 (orbital->quaternion, rotate);
+  glMultMatrixd (rotate);
+
+  dots = orbital->dots;
+
+  glLineWidth (4.0);
+  if (dots[1] > 0)
+    gamgi_mesa_render_points (dots[1], orbital->points + 3 * dots[0]);
+  if (dots[2] > 0)
+    gamgi_mesa_render_points (dots[2], orbital->points + 3 * dots[0] + 3 * dots[1]);
+  glLineWidth (1.0);
+
+  if (dots[0] > 0)
+    gamgi_mesa_render_lines (orbital->lines, orbital->points);
+  if (orbital->axes == TRUE)
+    gamgi_mesa_axes_orbital (orbital, FALSE);
+
+  glPopMatrix ();
+  }
+
 /****************************
  * scan child objects: text *
  ****************************/
@@ -1083,7 +1120,7 @@ else
         }
 
       gamgi_mesa_render_loops (cluster->loops, cluster->points);
-      if (cluster->dots == TRUE)
+      if (cluster->n_dots > 0)
         gamgi_mesa_render_points (cluster->n_dots, cluster->points);
 
       glDisable (GL_POLYGON_OFFSET_FILL);
