@@ -86,6 +86,10 @@ gamgi_object **gamgi_mesa_pick_orbital (gamgi_orbital *orbital, int class, gamgi
 {
 gamgi_dlist *dlist;
 unsigned char color_old[3], color_new[3];
+double rotate[16];
+double *center;
+double scale;
+int *dots;
 
 if (class == GAMGI_ENGINE_ORBITAL)
   {
@@ -95,7 +99,45 @@ if (class == GAMGI_ENGINE_ORBITAL)
   glColor3ubv (color_new);
   }
 
-/* scan text list */
+glPushMatrix ();
+
+center = orbital->center;
+scale = orbital->object.scale;
+glTranslatef (center[0], center[1], center[2]);
+glScalef (scale, scale, scale);
+glTranslatef (-center[0], -center[1], -center[2]);
+
+glPushMatrix ();
+
+glTranslatef (orbital->origin[0], orbital->origin[1], orbital->origin[2]);
+
+gamgi_math_quaternion_to_matrix4 (orbital->quaternion, rotate);
+glMultMatrixd (rotate);
+
+/***********************
+ * scan orbital object *
+ ***********************/
+
+dots = orbital->dots;
+
+glLineWidth (4.0);
+if (dots[1] > 0)
+  gamgi_mesa_render_points (dots[1], orbital->points + 3 * dots[0]);
+if (dots[2] > 0)
+  gamgi_mesa_render_points (dots[2], orbital->points + 3 * dots[0] + 3 * dots[1]);
+glLineWidth (1.0);
+
+if (dots[0] > 0)
+  gamgi_mesa_render_lines (orbital->lines, orbital->points);
+if (orbital->axes == TRUE)
+  gamgi_mesa_axes_orbital (orbital, FALSE);
+
+glPopMatrix ();
+
+/**********************
+ * scan orbital child *
+ **********************/
+
 dlist = orbital->text_start;
 while (dlist != NULL)
   { array = gamgi_mesa_pick_text (GAMGI_CAST_TEXT dlist->data, class, array);
@@ -103,6 +145,8 @@ while (dlist != NULL)
 
 if (class == GAMGI_ENGINE_ORBITAL) glColor3ubv (color_old);
 
+glPopMatrix ();
+
 return array;
 }
 
@@ -765,7 +809,7 @@ else
       }
 
     gamgi_mesa_render_loops (cluster->loops, cluster->points);
-    if (cluster->dots == TRUE)
+    if (cluster->n_dots > 0)
       gamgi_mesa_render_points (cluster->n_dots, cluster->points);
 
     glDisable (GL_POLYGON_OFFSET_FILL);
