@@ -49,6 +49,25 @@ gamgi_math_quaternion_add (quaternion, text->quaternion, text->quaternion);
 void gamgi_mesa_rotate_out_orbital (gamgi_orbital *orbital, 
 double *quaternion, double *rotate, double *center)
 {
+double v1[3], v2[3];
+
+/*************************
+ * rotate orbital origin *
+ *************************/
+
+gamgi_math_vector_sub (orbital->origin, center, v1);
+gamgi_math_matrix_vector (rotate, v1, v2);
+gamgi_math_vector_add (v2, center, orbital->origin);
+
+/*************************
+ * rotate orbital center *
+ *************************/
+
+gamgi_math_vector_sub (orbital->center, center, v1);
+gamgi_math_matrix_vector (rotate, v1, v2);
+gamgi_math_vector_add (v2, center, orbital->center);
+
+gamgi_math_quaternion_add (quaternion, orbital->quaternion, orbital->quaternion);
 }
 
 void gamgi_mesa_rotate_out_atom (gamgi_atom *atom, 
