@@ -173,7 +173,7 @@ int i, color, n = gamgi->gamgi->tolerance;
 int pixels;
 unsigned char *rgb;
 gamgi_slist *slist = NULL;
-int r0, r1, g0, g1, b0, b1;
+int r0, g0, b0, g1, b1;
 
 pixels = pow (2*n + 1, 2);
 
@@ -183,12 +183,10 @@ pixels = pow (2*n + 1, 2);
  *****************************************************/
 
 r0 = pow (2, gamgi->r);
-r1 = pow (2, 8 - gamgi->r);
-
 g0 = pow (2, gamgi->g);
-g1 = pow (2, 8 - gamgi->g);
-
 b0 = pow (2, gamgi->b);
+
+g1 = pow (2, 8 - gamgi->g);
 b1 = pow (2, 8 - gamgi->b);
 
 /*********************************************************************
@@ -239,7 +237,7 @@ gamgi_object **objects, int *levels, int level, gamgi_slist *slist)
 int i, color;
 int pixels;
 unsigned char *rgb;
-int r0, r1, g0, g1, b0, b1;
+int r0, g0, b0, g1, b1;
 
 pixels = width * height;
 
@@ -249,12 +247,10 @@ pixels = width * height;
  *****************************************************/
 
 r0 = pow (2, gamgi->r);
-r1 = pow (2, 8 - gamgi->r);
-
 g0 = pow (2, gamgi->g);
-g1 = pow (2, 8 - gamgi->g);
-
 b0 = pow (2, gamgi->b);
+
+g1 = pow (2, 8 - gamgi->g);
 b1 = pow (2, 8 - gamgi->b);
 
 /***********************************************************************
