@@ -34,6 +34,17 @@ gamgi_math_vector_add (text->center, translate, text->center);
 void gamgi_mesa_translate_out_orbital (gamgi_orbital *orbital, 
 double *translate)
 {
+/********************
+ * translate origin *
+ ********************/
+
+gamgi_math_vector_add (orbital->origin, translate, orbital->origin);
+
+/********************
+ * translate center *
+ ********************/
+
+gamgi_math_vector_add (orbital->center, translate, orbital->center);
 }
 
 void gamgi_mesa_translate_out_atom (gamgi_atom *atom, 
