@@ -742,7 +742,7 @@ int points_offset, vertices_offset;
 int loops_offset, lines_offset;
 int *loops, *lines;
 double translate[3], c1[3], c2[3];
-double a, b, c, x, y, z, aux;
+double a, c, x, y, z, aux;
 double *points;
 gamgi_bool k0, k1, j0, j1, i0, i1;
 gamgi_bool local1, local2, local3, local4, local5, local6;
@@ -799,9 +799,7 @@ gamgi_math_vector_add (translate, cell->p1, c1);
 gamgi_math_vector_add (translate, cell->p2, c2);
 
 a = cell->a;
-b = cell->b;
 c = cell->c;
-
 aux = a * sqrt(3)/2;
 
 global_edges = (cell->borders != GAMGI_PHYS_EDGES);
