@@ -1263,13 +1263,28 @@ gamgi_direction *direction_new;
 double rotate[9];
 double vector[3], normal[3];
 
+/******************************************************************
+ * Direction Create: direction is just a template, removed in the *
+ * end, used to copy data to direction_new, the real direction    *
+ *                                                                *
+ * Direction Modify: direction is the real direction to modify    *
+ *                                                                *
+ * direction->object.object is used here as a flag to distinguish *
+ * between the two cases. direction->object.object can be used    *
+ * because direction is always unlinked at this stage             *
+ ******************************************************************/
+
+if (direction->object.object == NULL)
+  direction_new = gamgi_engine_copy_direction (direction);
+else
+  { direction_new = direction; direction->object.object = NULL; }
+
 /*********************************************
  * 1) build new direction and link to cell   *
  * 2) get normalized direction vector,       *
  * rotated according to the cell orientation *
  *********************************************/
 
-direction_new = gamgi_engine_copy_direction (direction);
 gamgi_phys_direction_cell (direction_new, cell);
 gamgi_engine_link_direction_cell (direction_new, cell);
 
@@ -1294,40 +1309,30 @@ gamgi_cell *cell, gamgi_enum pole, gamgi_enum trace)
 {
 gamgi_direction *direction_new;
 
-if (pole == TRUE)
-  {
-  /***********************************************
-   *                  allocate data              *
-   *                                             *
-   * link direction to cell before building pole *
-   ***********************************************/
+/******************************************************************
+ * Direction Create: direction is just a template, removed in the *
+ * end, used to copy data to direction_new, the real direction    *
+ *                                                                *
+ * Direction Modify: direction is the real direction to modify    *
+ *                                                                *
+ * direction->object.object is used here as a flag to distinguish *
+ * between the two cases. direction->object.object can be used    *
+ * because direction is always unlinked at this stage             *
+ ******************************************************************/
 
+if (direction->object.object == NULL)
   direction_new = gamgi_engine_copy_direction (direction);
-  direction_new->type = GAMGI_PHYS_POLE;
-  gamgi_phys_projection_create (GAMGI_PHYS_POLE, &direction_new->points,
-  &direction_new->n_points, &direction_new->loops, &direction_new->n_loops);
+else
+  { direction_new = direction; direction->object.object = NULL; }
 
-  gamgi_engine_link_direction_cell (direction_new, cell);
-  gamgi_mesa_rotate_out_direction (direction_new, NULL, NULL, NULL);
-  }
+if (pole == TRUE) direction_new->type = GAMGI_PHYS_POLE;
+if (trace == TRUE) direction_new->type = GAMGI_PHYS_TRACE;
 
-if (trace == TRUE)
-  {
-  /************************************************
-   *                   allocate data              *
-   *                                              *
-   * link direction to cell before building trace *
-   ************************************************/
-
-  direction_new = gamgi_engine_copy_direction (direction);
-  direction_new->type = GAMGI_PHYS_TRACE;
-  gamgi_phys_projection_create (GAMGI_PHYS_TRACE, &direction_new->points,
-  &direction_new->n_points, &direction_new->loops, &direction_new->n_loops);
-
-  gamgi_engine_link_direction_cell (direction_new, cell);
-  gamgi_mesa_rotate_out_direction (direction_new, NULL, NULL, NULL);
-  }
+gamgi_phys_projection_create (direction_new->type, &direction_new->points,
+&direction_new->n_points, &direction_new->loops, &direction_new->n_loops);
 
+gamgi_engine_link_direction_cell (direction_new, cell);
+gamgi_mesa_rotate_out_direction (direction_new, NULL, NULL, NULL);
 }
 
 void gamgi_phys_direction_line (gamgi_direction *direction, double *points)
