@@ -996,11 +996,22 @@ double *normal, gamgi_bool link)
 gamgi_plane *plane_new;
 gamgi_bool inside;
 
-/********************
- * create new plane *
- ********************/
+/**************************************************************
+ * Plane Create: plane is just a template, removed in the     *
+ * end, used to copy data to plane_new, the real plane        *
+ *                                                            *
+ * Plane Modify: plane is the real plane, the plane to modify *
+ *                                                            *
+ * plane->object.object is used here as a flag to distinguish *
+ * between the two cases. plane->object.object can be used    *
+ * because plane is always unlinked at this stage             *
+ **************************************************************/
+
+if (plane->object.object == NULL)
+  plane_new = gamgi_engine_copy_plane (plane);
+else
+  { plane_new = plane; plane->object.object = NULL; }
 
-plane_new = gamgi_engine_copy_plane (plane);
 plane_new->order = order;
 
 /*******************
@@ -1857,38 +1868,28 @@ gamgi_cell *cell, gamgi_enum pole, gamgi_enum trace)
 {
 gamgi_plane *plane_new;
 
-if (pole == TRUE)
-  {
-  /*******************************************
-   *               allocate data             *
-   *                                         *
-   * link plane to cell before building pole *
-   *******************************************/
+/**************************************************************
+ * Plane Create: plane is just a template, removed in the     *
+ * end, used to copy data to plane_new, the real plane        *
+ *                                                            *
+ * Plane Modify: plane is the real plane to modify            *
+ *                                                            *
+ * plane->object.object is used here as a flag to distinguish *
+ * between the two cases. plane->object.object can be used    *
+ * because plane is always unlinked at this stage             *
+ **************************************************************/
 
+if (plane->object.object == NULL)
   plane_new = gamgi_engine_copy_plane (plane);
-  plane_new->type = GAMGI_PHYS_POLE;
-  gamgi_phys_projection_create (GAMGI_PHYS_POLE, &plane_new->points,
-  &plane_new->n_points, &plane_new->loops, &plane_new->n_loops);
+else
+  { plane_new = plane; plane->object.object = NULL; }
 
-  gamgi_engine_link_plane_cell (plane_new, cell);
-  gamgi_mesa_rotate_out_plane (plane_new, NULL, NULL, NULL);
-  }
+if (pole == TRUE) plane_new->type = GAMGI_PHYS_POLE;
+if (trace == TRUE) plane_new->type = GAMGI_PHYS_TRACE;
 
-if (trace == TRUE)
-  {
-  /********************************************
-   *               allocate data              *
-   *                                          *
-   * link plane to cell before building trace *
-   ********************************************/
-
-  plane_new = gamgi_engine_copy_plane (plane);
-  plane_new->type = GAMGI_PHYS_TRACE;
-  gamgi_phys_projection_create (GAMGI_PHYS_TRACE, &plane_new->points,
-  &plane_new->n_points, &plane_new->loops, &plane_new->n_loops);
-
-  gamgi_engine_link_plane_cell (plane_new, cell);
-  gamgi_mesa_rotate_out_plane (plane_new, NULL, NULL, NULL);
-  }
+gamgi_phys_projection_create (plane_new->type, &plane_new->points,
+&plane_new->n_points, &plane_new->loops, &plane_new->n_loops);
 
+gamgi_engine_link_plane_cell (plane_new, cell);
+gamgi_mesa_rotate_out_plane (plane_new, NULL, NULL, NULL);
 }
